import pytest
from mcp_server_notion.server import call_tool

class DummyNotion:
    def __init__(self):
        self.pages = self
    def create(self, parent, properties, children):
        assert parent["database_id"] == "dummy_db"
        assert properties["title"][0]["text"]["content"] == "테스트"
        assert children[0]["paragraph"]["rich_text"][0]["text"]["content"] == "본문"
        return {"url": "https://notion.so/dummy"}

def test_notion_create_page(monkeypatch):
    import mcp_server_notion.server as server
    server.Client = lambda auth: DummyNotion()
    result = pytest.run(asyncio_run(call_tool("notion_create_page", {
        "notion_token": "dummy_token",
        "parent_id": "dummy_db",
        "title": "테스트",
        "content": "본문"
    })))
    assert result[0].text == "페이지 생성됨: https://notion.so/dummy"

def asyncio_run(coro):
    import asyncio
    return asyncio.get_event_loop().run_until_complete(coro)


from mcp.server import Server
from mcp.types import Tool, TextContent
from pydantic import BaseModel
from notion_client import Client

class NotionCreatePageInput(BaseModel):
    notion_token: str
    parent_id: str
    title: str
    content: str

server = Server("mcp-notion")

@server.list_tools()
async def list_tools():
    return [
        Tool(
            name="notion_create_page",
            description="Notion에 새 페이지를 생성",
            inputSchema=NotionCreatePageInput.schema(),
        ),
    ]

@server.call_tool()
async def call_tool(name: str, arguments: dict):
    if name == "notion_create_page":
        notion = Client(auth=arguments["notion_token"])
        new_page = notion.pages.create(
            parent={"database_id": arguments["parent_id"]},
            properties={
                "title": [
                    {
                        "type": "text",
                        "text": {"content": arguments["title"]}
                    }
                ]
            },
            children=[
                {
                    "object": "block",
                    "type": "paragraph",
                    "paragraph": {
                        "rich_text": [
                            {
                                "type": "text",
                                "text": {"content": arguments["content"]}
                            }
                        ]
                    }
                }
            ]
        )
        return [TextContent(type="text", text=f"페이지 생성됨: {new_page['url']}")]
    raise ValueError(f"Unknown tool: {name}")

def main():
    import asyncio
    asyncio.run(server.run_stdio())

if __name__ == "__main__":
    main()
